@@ -26,7 +26,7 @@
 from inspect import getmro
 
 import copy
-import types, sets
+import types
 types.ImmutableTypes = tuple([ \
     types.BooleanType, \
     types.ComplexType, \
@@ -35,7 +35,7 @@ types.ImmutableTypes = tuple([ \
     types.LongType, \
     types.NoneType, \
     types.TupleType, \
-    sets.ImmutableSet] + \
+    frozenset] + \
     list(types.StringTypes))
 
 MUTABLE = "__mutable__"
