@@ -128,12 +128,13 @@ def init(urls, d, setup = True):
     urldata_cache[fn] = urldata
     return urldata
 
-def go(d):
+def go(d, urls = None):
     """
     Fetch all urls
     init must have previously been called
     """
-    urls = d.getVar("SRC_URI", 1).split()
+    if not urls:
+        urls = d.getVar("SRC_URI", 1).split()
     urldata = init(urls, d, True)
 
     for u in urls:
@@ -333,9 +334,11 @@ class FetchData(object):
             # if user sets localpath for file, use it instead.
             self.localpath = self.parm["localpath"]
         else:
-            bb.fetch.srcrev_internal_call = True
-            self.localpath = self.method.localpath(self.url, self, d)
-            bb.fetch.srcrev_internal_call = False
+            try:
+                bb.fetch.srcrev_internal_call = True
+                self.localpath = self.method.localpath(self.url, self, d)
+            finally:
+                bb.fetch.srcrev_internal_call = False
             # We have to clear data's internal caches since the cached value of SRCREV is now wrong.
             # Horrible...
             bb.data.delVar("ISHOULDNEVEREXIST", d)
